@@ -18,29 +18,27 @@
 
 from .block_user import BlockUser
 from .delete_profile_photos import DeleteProfilePhotos
+from .get_chat_photos import GetChatPhotos
+from .get_chat_photos_count import GetChatPhotosCount
 from .get_common_chats import GetCommonChats
 from .get_me import GetMe
-from .get_profile_photos import GetProfilePhotos
-from .get_profile_photos_count import GetProfilePhotosCount
 from .get_users import GetUsers
-from .iter_profile_photos import IterProfilePhotos
 from .set_profile_photo import SetProfilePhoto
+from .set_username import SetUsername
 from .unblock_user import UnblockUser
 from .update_profile import UpdateProfile
-from .update_username import UpdateUsername
 
 
 class Users(
     BlockUser,
     GetCommonChats,
-    GetProfilePhotos,
+    GetChatPhotos,
     SetProfilePhoto,
     DeleteProfilePhotos,
     GetUsers,
     GetMe,
-    UpdateUsername,
-    GetProfilePhotosCount,
-    IterProfilePhotos,
+    SetUsername,
+    GetChatPhotosCount,
     UnblockUser,
     UpdateProfile,
 ):
