@@ -1,5 +1,5 @@
 #  Pyrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
+#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
 #
 #  This file is part of Pyrogram.
 #
@@ -18,17 +18,19 @@
 
 import logging
 
+import pyrogram
 from pyrogram import raw
-from pyrogram.scaffold import Scaffold
 
 log = logging.getLogger(__name__)
 
 
-class Start(Scaffold):
-    async def start(self):
+class Start:
+    async def start(
+        self: "pyrogram.Client"
+    ):
         """Start the client.
 
-        This method connects the client to Telegram and, in case of new sessions, automatically manages the full
+        This method connects the client to Telegram and, in case of new sessions, automatically manages the
         authorization process using an interactive prompt.
 
         Returns:
@@ -39,16 +41,19 @@ class Start(Scaffold):
 
         Example:
             .. code-block:: python
-                :emphasize-lines: 4
 
                 from pyrogram import Client
 
                 app = Client("my_account")
-                app.start()
 
-                ...  # Call API methods
 
-                app.stop()
+                async def main():
+                    await app.start()
+                    ...  # Invoke API methods
+                    await app.stop()
+
+
+                app.run(main())
         """
         is_authorized = await self.connect()
 
@@ -57,17 +62,10 @@ class Start(Scaffold):
                 await self.authorize()
 
             if not await self.storage.is_bot() and self.takeout:
-                self.takeout_id = (await self.send(raw.functions.account.InitTakeoutSession(
-                    contacts=True,
-                    message_users=True,
-                    message_chats=True,
-                    message_megagroups=True,
-                    message_channels=True,
-                    files=False
-                ))).id
+                self.takeout_id = (await self.invoke(raw.functions.account.InitTakeoutSession())).id
                 log.warning(f"Takeout session {self.takeout_id} initiated")
 
-            await self.send(raw.functions.updates.GetState())
+            await self.invoke(raw.functions.updates.GetState())
         except (Exception, KeyboardInterrupt):
             await self.disconnect()
             raise
